# python-arkhamdb

![pypi_license](https://img.shields.io/pypi/l/arkhamdb)[![status-badge](https://ci.jamesveitch.xyz/api/badges/james/python-arkhamdb/status.svg)](https://ci.jamesveitch.xyz/james/python-arkhamdb)[![Read the Docs](https://readthedocs.org/projects/arkhamdb/badge/)](https://arkhamdb.readthedocs.io/)
![pypi_versions](https://img.shields.io/pypi/v/arkhamdb)![pypi_python](https://img.shields.io/pypi/pyversions/arkhamdb)![pypi_downloads](https://img.shields.io/pypi/dm/arkhamdb)

<img src="https://arkhamdb.readthedocs.io/en/latest/_static/logo.svg" width="100" style="float:left;clear:both;margin-right:10px"/> Pythonic wrapper around the excellent [ArkhamDB API](https://arkhamdb.com/api/). Designed to be standalone and importable to other projects.

Documentation can be found at [arkhamdb.readthedocs.io](https://arkhamdb.readthedocs.io). See the [latest](https://arkhamdb.readthedocs.io/en/latest/) branch for the master (stable) code and [develop](https://arkhamdb.readthedocs.io/en/develop/) for current (unstable) working version of the code.

## Simple usage

TODO: add example

## Python Version

This library is tested against Python 3.7+
